Index: trunk/src/org/openstreetmap/josm/gui/GettingStarted.java
===================================================================
--- trunk/src/org/openstreetmap/josm/gui/GettingStarted.java	(revision 17298)
+++ trunk/src/org/openstreetmap/josm/gui/GettingStarted.java	(revision 17299)
@@ -57,5 +57,5 @@
             + "body {font-family: sans-serif; font-weight: bold; }\n"
             + "h1 {text-align: center; }\n"
-            + "a {color: " + JosmEditorPane.getLinkColor("#316ed9") + "; }\n"
+            + "a {color: " + JosmEditorPane.getLinkColor() + "; }\n"
             + ".icon {font-size: 0; }\n"
             + "</style>\n";
Index: trunk/src/org/openstreetmap/josm/gui/help/HelpBrowser.java
===================================================================
--- trunk/src/org/openstreetmap/josm/gui/help/HelpBrowser.java	(revision 17298)
+++ trunk/src/org/openstreetmap/josm/gui/help/HelpBrowser.java	(revision 17299)
@@ -138,5 +138,5 @@
 
         // overwrite link color
-        String linkColor = JosmEditorPane.getLinkColor(null);
+        String linkColor = JosmEditorPane.getLinkColor();
         if (linkColor != null) {
             ss.addRule("a {color: " + linkColor + "}");
Index: trunk/src/org/openstreetmap/josm/gui/widgets/HtmlPanel.java
===================================================================
--- trunk/src/org/openstreetmap/josm/gui/widgets/HtmlPanel.java	(revision 17298)
+++ trunk/src/org/openstreetmap/josm/gui/widgets/HtmlPanel.java	(revision 17299)
@@ -57,5 +57,5 @@
                 f.isItalic() ? "italic" : "normal"
         ) + '}');
-        ss.addRule("a {text-decoration: underline; color: " + JosmEditorPane.getLinkColor("blue") + "}");
+        ss.addRule("a {text-decoration: underline; color: " + JosmEditorPane.getLinkColor() + "}");
         ss.addRule("ul {margin-left: 1cm; list-style-type: disc}");
         JosmHTMLEditorKit kit = new JosmHTMLEditorKit();
Index: trunk/src/org/openstreetmap/josm/gui/widgets/UrlLabel.java
===================================================================
--- trunk/src/org/openstreetmap/josm/gui/widgets/UrlLabel.java	(revision 17298)
+++ trunk/src/org/openstreetmap/josm/gui/widgets/UrlLabel.java	(revision 17299)
@@ -93,5 +93,5 @@
     protected final void refresh() {
         if (url != null && !url.isEmpty()) {
-            refresh("<html><a href=\""+url+"\">"+description+"</a></html>",
+            refresh("<html><a color=\"" + JosmEditorPane.getLinkColor() + "\" href=\"" + url + "\">" + description + "</a></html>",
                     Cursor.getPredefinedCursor(Cursor.HAND_CURSOR),
                     String.format("<html>%s<br/>%s</html>", url, tr("Right click = copy to clipboard")));

Index: trunk/src/org/openstreetmap/josm/gui/widgets/JosmEditorPane.java
===================================================================
--- trunk/src/org/openstreetmap/josm/gui/widgets/JosmEditorPane.java	(revision 17298)
+++ trunk/src/org/openstreetmap/josm/gui/widgets/JosmEditorPane.java	(revision 17299)
@@ -102,5 +102,5 @@
         final StyleSheet ss = new StyleSheet();
         ss.addRule((allBold ? "html" : "strong, b") + " {" + getFontRule(f) + '}');
-        ss.addRule("a {text-decoration: underline; color: " + getLinkColor("blue") + "}");
+        ss.addRule("a {text-decoration: underline; color: " + getLinkColor() + "}");
         ss.addRule("h1 {" + getFontRule(GuiHelper.getTitleFont()) + '}');
         ss.addRule("ol {margin-left: 1cm; margin-top: 0.1cm; margin-bottom: 0.2cm; list-style-type: decimal}");
@@ -144,11 +144,10 @@
     /**
      * Returns the color (in CSS format) that should be used for links.
      * If the current look and feel does not provide a link color, the passed default color is used.
      * @param defaultColor the default color
      * @return link color
      */
-    public static String getLinkColor(String defaultColor) {
+    public static String getLinkColor() {
         Color color = UIManager.getColor("Component.linkColor");
-        return color != null ? ColorHelper.color2html(color) : defaultColor;
+        return color != null ? ColorHelper.color2html(color) : "#316ed9";
     }
 
@@ -144,11 +144,10 @@
     /**
      * Returns the color (in CSS format) that should be used for links.
-     * If the current look and feel does not provide a link color, the passed default color is used.
-     * @param defaultColor the default color
+     * If the current look and feel does not provide a link color, the JOSM blue {@code #316ed9} is returned.
      * @return link color
      */